@@ -4,4 +4,7 @@ import py_cpu
 cpu_info = py_cpu.CPUInfo()
 
 #call pprint method
-cpu_info.print_as_table()
\ No newline at end of file
+cpu_info.print_as_table()
+
+#subscriptable:
+print(cpu_info['arch'])
\ No newline at end of file
